/* AICLLF -- computes LLF and AIC values for specified objective
**           functions
**
** FORMAT: {AIC,LLF} = aicllf(data,param,&fct)
**
** INPUTS: data = TxK matrix of data for LLF
**         param = Kx1 vector of parameters
**         &fct = likelihood function to be evaluated
**
** OUTPUTS: AIC = Akaike's Information Criterion
**	    LLF = Log-likelihood value
**
** Date: July 13, 1998
*/

proc (2) = aicllf(data,param,&fct);
    local n,k,fct:proc,llf,aic;
    k = cols(data)-1;
    llf = sumc(fct(param,data));
    aic = -2.*llf + 2.*k;
print " ";
print "------------------------------------------------------------";
print " ";
print "Model AIC:      ";;aic;
print "Model Final LLF:";;llf;
print " ";
print "------------------------------------------------------------";
retp(aic,llf);
endp;

