/* BETARNG Beta Random Number Generator
**
** Purpose: proc to generate a BET(a,b) random variable through
** the acceptance-rejection method
**
** Used for: "Monte Carlo Simulation" Sage monograph
** Date: September 13, 1996
**
** Author: Chris Mooney
**
** THE FOLLOWING IS HOW YOU WOULD CALL THIS PROC IN A PROGRAM TO
** GENERATE x DISTRIBUTED AS BET(a,b)
**
** USAGE: x = betarng(a,b,n)
**              where a and b are the parameters of the beta
**              distribution desired
**
*/

PROC betarng(a,b,n);
    local x,mode,peak,prob,density,i,beta,trial;

x = zeros(n,1);
i=1;

/* Step 1: calculate beta(a,b) function using gamma function */

beta = (gamma(a)*gamma(b))/gamma(a+b);
do until i > n;                 @Start do loop to go through cases@

/* Step 2: Draw two U(0,1) numbers */

if a > 1 and b > 1;         @ start calculations to find @
                            @ mode of distribution       @
mode = (a-1)/(a+b-2);       @calculate the mode of Be(a,b)@
peak=(mode^(a-1))*((1-mode)^(b-1))/beta; @calculate pdf value at mode@

else;

peak = 4;                   @ use 4 for peak when infinite peak exists,
                              ie, when a or b < 1 @
endif;

prob = rndu(1,1)*peak;      @density to use in accept/reject procedure@

trial = rndu(1,1);          @ number between 0 and 1
                              to use as the potential x value@

/*Step 3: Calculate pdf of x and compare to prob, accepting or rejecting */

density = (trial^(a-1))*((1-trial)^(b-1))/beta;
if prob <= density;     @compare random probability scalar to potential x@
x[i,1] = trial;         @accept trial as an x value if condition is met@
i = i +1;               @increment i if trial is accepted@

endif;
endo;
RETP (x) ;
ENDP ;

