/*-------------------------------------------------------------------
** EWMA - procedure for calculating exponentially weighted moving
**        averages
**
** USAGE : z = EWMA(x,omega);
**
** INPUT : x     = Nx1 vector
**         omega = scalar, the weight (0<w<=1)
**
** OUTPUT : z = exponentially weighted moving average of x
**
** Date; August 10, 1998
**
** Note: This procedure computes the exact EWMA weight.  It does not
**       approximate the forecast function, so it is a bit slow.
**
*/
proc ewma(x,omega);
    local t,w,j;
t = rows(x);
/* do loop to create weights */
w=1; j=1;
do while (j<t);
    if omega^j>1.0E-150;    @ keep all weights greater than 10^-150 @
     w = w|(omega^j);
    else;
     w = w|zeros(t-j,1);  @ truncate smaller weights to zero to   @
                            @ prevent underflow errors              @
        j=t;
    endif;
j=j+1;
endo;

retp( (rev(w)' * x)./sumc(w) );
endp;

/*-------------------------------------------------------------------*/

