/* EWMAEST -- EWMA estimator
**
** PURPOSE: Computes the optimal EWMA by minimizing the sum of squares.
**
** FORMAT: w = ewmaest(x)
**
** INPUT:  X = Tx1 vector to be smoothed
**
** OUTPUT: w = optimal weighting
**
** Comments:  This procedure minimzes the sum of forecast residuals for
**            the various values of w.  It uses a simple grid search to
**            find the optimal weight.  The grid is from 0.01 to 1.
**            If w = 1, then the optimal weight is the sample mean.
**            The value of w is exact, since the EWMA's are computed
**            without any approximations.  As a consequence, this procedure
**            will be very slow for large sample (i.e. T>100).
**            The smoothed vector can be found by using EWMAV(x,w);
**
** SEE ALSO: EWMA, EWMAV.
**
*/


proc(1)=ewmaest(x);
    local ssf,j,t,w;
ssf=zeros(100,2);
j=1; w = j.*0.01;
do until j>100;
    ssf[j,1] = sumc((x-ewmav(x,w))^2);
    ssf[j,2] = w;
    j = j+1;
    w = j.*0.01;
endo;
ssf = sortc(ssf,1);
retp(ssf[1,2]);
endp;

