/* EWMAV - Procedure for generating a vector exponentially weighted moving
**         average
**
** USAGE : z = EWMAV(x,omega);
**
** INPUT : x     = Nx1 vector
**         omega = scalar, the weight (0<w<=1)
**
** OUTPUT ; z = Nx1 vector of exponentially weighted moving average
**
** Note: EWMA's can be estimated using EWMAEST.  If omega==1, then the
**       procedure will return the sample mean.
**
** See also: EWMA, EWMAEST
*/

proc ewmav(x,omega);
    local n,t,y,w,z,j;
z = zeros(rows(x),1);
n = rows(x);
t=1;
do until t>n;
if t==1;
z[t,1] = x[1,1];
else;

/* do loop to create weights */
w=1; j=1;
do while (j<t-1);
    if omega^j>1.0E-300;    @ keep all weights greater than 10^-300  @
     w = w|(omega^j);
    else;
     w = w|zeros(t-1-j,1);  @ truncate smaller weights to zero to   @
                            @ prevent underflow errors              @
        j=t;
    endif;
j=j+1;
endo;

z[t,1] = (rev(w)'* x[1:t-1,.]) ./ sumc(w);
endif;
t=t+1;
endo;
retp(z);
endp;

