/* EXAMPLE 1: Event Count Time Series Analysis of Pacelle's Supreme Court
**            Agenda Data
**
** This file is an example of how to estimate PEWMA, PAR, and other event
** count models using the PESTS code.
**
** April 20, 1998
**
*/

/* Load the required libraries and initialize the workspace */

@library maxlik, pgraph@
@library F:\counts\code\pests\pests.lcg;@
format 8,6;

/* Read the data from the ASCII data file */

load dta[61,3] = sctdta.txt;
term = dta[.,1];        @ Court Term Variable        @
equal = dta[.,2];       @ Number of equality cases   @
reg = dta[.,3];         @ Number of regulation cases @

/* Create trend and intercept variables */
t = term-1932;                  @ Create the trend @
lnt = ln(t);                    @ Log trend        @
c = ones(61,1);                 @ Create intercept @

/* Create Brown v. Board and other interventions */
brown  = zeros(20,1)|1|zeros(40,1);
brown1 = zeros(21,1)|1|zeros(39,1);
brown2 = zeros(22,1)|1|zeros(38,1);
brown3 = zeros(23,1)|1|zeros(37,1);
brown4 = zeros(24,1)|1|zeros(36,1);
brown5 = zeros(25,1)|1|zeros(35,1);
brown6 = zeros(26,1)|1|zeros(34,1);
brown7 = zeros(27,1)|1|zeros(33,1);
brown8 = zeros(28,1)|1|zeros(32,1);
brown9 = zeros(29,1)|1|zeros(31,1);
brown10 = zeros(30,1)|1|zeros(30,1);
brown11 = zeros(31,1)|1|zeros(29,1);

/* Turn on output file */
output file = court.out;
output on reset;


/* Fit models for Equality series:
** 1) Fit Models to determine optimal lag for intervention
** 2) Generate the predictions for best model
**
** Note that the previous models values are used as starting values
** in the next model to speed things up.
*/

/* PEWMA model for Equality series */
_mlalgr = 6;
_mlparnm = {"Omega","BvBp"};
{o0,d0,cov0,llf0,aic0} = pewma(equal,brown,"P");
_mlparnm = {"Omega","BvBp-1"};
{o1,d1,cov1,llf1,aic1} = pewma(equal,brown1,o0|d0);
_mlparnm = {"Omega","BvBp-2"};
{o2,d2,cov2,llf2,aic2} = pewma(equal,brown2,o1|d1);
_mlparnm = {"Omega","BvBp-3"};
{o3,d3,cov3,llf3,aic3} = pewma(equal,brown3,o2|d2);
_mlparnm = {"Omega","BvBp-4"};
{o4,d4,cov4,llf4,aic4} = pewma(equal,brown4,o3|d3);
_mlparnm = {"Omega","BvBp-5"};
{o5,d5,cov5,llf5,aic5} = pewma(equal,brown5,o4|d4);
_mlparnm = {"Omega","BvBp-6"};
{o6,d6,cov6,llf6,aic6} = pewma(equal,brown6,o5|d5);
_mlparnm = {"Omega","BvBp-7"};
{o7,d7,cov7,llf7,aic7} = pewma(equal,brown7,o6|d6);
_mlparnm = {"Omega","BvBp-8"};
{o8,d8,cov8,llf8,aic8} = pewma(equal,brown8,o7|d7);
_mlparnm = {"Omega","BvBp-9"};
{o9,d9,cov9,llf9,aic9} = pewma(equal,brown9,o8|d8);
_mlparnm = {"Omega","BvBp-10"};
{o10,d10,cov10,llf10,aic10} = pewma(equal,brown10,o9|d9);
_mlparnm = {"Omega","BvBp-11"};
{o11,d11,cov11,llf11,aic11} = pewma(equal,brown11,o10|d10);

print;
print "-----------------------------------------------------------------";
print "PEWMA estimates for equality series with interventions";
print "-----------------------------------------------------------------";
print "Intervention period      Omega   I(t)    Log-lik     AIC";
print "       1953           ";;o0~d0~llf0~aic0;
print "       1954           ";;o1~d1~llf1~aic1;
print "       1955           ";;o2~d2~llf2~aic2;
print "       1956           ";;o3~d3~llf3~aic3;
print "       1957           ";;o4~d4~llf4~aic4;
print "       1958           ";;o5~d5~llf5~aic5;
print "       1959           ";;o6~d6~llf6~aic6;
print "       1960           ";;o7~d7~llf7~aic7;
print "       1961           ";;o8~d8~llf8~aic8;
print "       1962           ";;o9~d9~llf9~aic9;
print "       1963           ";;o10~d10~llf10~aic10;
print "       1964           ";;o11~d11~llf11~aic11;
print "-----------------------------------------------------------------";
print;
print;


/* Now generate the fitted series for the best model */

{a,aa,aaa,b,bb,bbb,mu,r} = pewma_filter(equal,brown10,o10,d10);
eqpma = trimr(aa,1,0)./trimr(bb,1,0);

/*---------------------------------------------------------------------*/

/* Fit models for Regulation series:
** 1) Fit Models to determine optimal lag for intervention
** 2) Generate the predictions for best model
*/


print "Econ reg, PEWMA and temp. intervention";
print;
_mlparnm = {"Omega","BvBp"};
{o0,d0,cov0,llf0,aic0} = pewma(reg,brown,"P");
_mlparnm = {"Omega","BvBp-1"};
{o1,d1,cov1,llf1,aic1} = pewma(reg,brown1,o0|d0);
_mlparnm = {"Omega","BvBp-2"};
{o2,d2,cov2,llf2,aic2} = pewma(reg,brown2,o1|d1);
_mlparnm = {"Omega","BvBp-3"};
{o3,d3,cov3,llf3,aic3} = pewma(reg,brown3,o2|d2);
_mlparnm = {"Omega","BvBp-4"};
{o4,d4,cov4,llf4,aic4} = pewma(reg,brown4,o3|d3);
_mlparnm = {"Omega","BvBp-5"};
{o5,d5,cov5,llf5,aic5} = pewma(reg,brown5,o4|d4);

print;
print "-----------------------------------------------------------------";
print "PEWMA estimates for economic regulation series with interventions";
print "-----------------------------------------------------------------";
print "Intervention period      Omega   I(t)    Log-lik     AIC";
print "       1953           ";;o0~d0~llf0~aic0;
print "       1954           ";;o1~d1~llf1~aic1;
print "       1955           ";;o2~d2~llf2~aic2;
print "       1956           ";;o3~d3~llf3~aic3;
print "       1957           ";;o4~d4~llf4~aic4;
print "       1958           ";;o5~d5~llf5~aic5;
print "-----------------------------------------------------------------";

print;
print;

/* Now generate the fitted series for the best model */

{a,aa,aaa,b,bb,bbb,mu,r} = pewma_filter(reg,brown1,o1,d1);
regpma = trimr(aa,1,0)./trimr(bb,1,0);

/* Turn off output file */
output off;

/*---------------------------------------------------------------------*/



