/* PARPFILT - Filter for Poisson AR(p) model
**
** Format: {m,s} = parpfilt(y,x,r,d);
**
** Inputs : y = Tx1 vector of counts
**          x = TxK matrix of covariates
**          p = AR(p) coefficients
**          d = Kx1 matrix of parameter for covariates
**
** Outputs : m = vector of conditional mean (t|t-1) in period t
**           s = vector of conditional variance (t|t-1) in period t
**
** Date: July 13, 1998
**
*/
proc (2) = parpfilt(y,x,r,d);
    local t,s,m,k,p,yl;

/* set up matrices for outputs */
k = cols(x);
m = zeros(rows(y),1);
s = zeros(rows(y),1);
p = rows(r);

t=1;
do until t>rows(y);
if t<p+2;
    m[t,1] = meanc(y);
    s[t,1] = stdc(y)^2;
else;
    yl = y[t-p:t-1,1]'*rev(r);
    m[t,1] = yl + (1-(sumc(r))).*(exp(x[t,.]*d));

    s[t,1] = sumc(r^2).*stdc(y[1:t-1,1])^2 +
            (1-sumc(r^2)).*stdc(exp(x[1:t-1,.]*d))^2;
endif;
t = t+1;
endo;
retp(m,s);
endp;

