/* PARPDGP Poisson Dynamic General Linear model simulator
**
** Purpose: Generates Poisson distributed random variables
**          that have a gamma distributed AR(p) prior
**          Data follows a state-space model with:
**
**              y(t)~Po(mu(t))
**
**              mu(t)~p*y(t-1) + (1-p)mu
**
**
** USAGE: {y} = parpdgp(n,x,r,d);
**
**       y = PAR(p) distributed vector
**       n = length of sample path
**       x = vector of covariates (nxk--with a constant)
**       r = Px1 weighting parameter for AR(p)
**       d = kx1 vector of parameters for link function
**
** Date: July 13, 1998
**
**/
proc (1) = parpdgp(n,x,r,d);
    local t,m,y,p,yl;

/* initialize matrices */
y = zeros(n,1);
m = zeros(n,1);
p = rows(r);
t = 1;
do until t>n;
if t<p+1;
    m[t,1] = exp(x[t,.]*d);
    y[t,1] = rndp(1,1,m[t,1]);
else;
    yl = y[t-p:t-1,1]'*rev(r);
    m[t,1] = yl + (1-(sumc(r))).*(exp(x[t,.]*d));
    y[t,1] = rndp(1,1,m[t,1]);

endif;
t = t+1;
endo;
retp(y);
endp;

